==> zio-aws-rds_2.12-5.17.129.1-sources.jar: zio/aws/rds/model/DescribeReservedDbInstancesRequest.scala <==
package zio.aws.rds.model
import java.lang.Integer
import zio.aws.rds.model.primitives.{IntegerOptional, BooleanOptional}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeReservedDbInstancesRequest(
    reservedDBInstanceId: scala.Option[String] = None,
    reservedDBInstancesOfferingId: scala.Option[String] = None,
    dbInstanceClass: scala.Option[String] = None,
    duration: scala.Option[String] = None,
    productDescription: scala.Option[String] = None,
    offeringType: scala.Option[String] = None,
    multiAZ: scala.Option[BooleanOptional] = None,
    leaseId: scala.Option[String] = None,
    filters: scala.Option[Iterable[zio.aws.rds.model.Filter]] = None,
    maxRecords: scala.Option[IntegerOptional] = None,
    marker: scala.Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeReservedDbInstancesRequest = {
    import DescribeReservedDbInstancesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeReservedDbInstancesRequest
      .builder()
      .optionallyWith(
        reservedDBInstanceId.map(value => value: java.lang.String)
      )(_.reservedDBInstanceId)
      .optionallyWith(
        reservedDBInstancesOfferingId.map(value => value: java.lang.String)
      )(_.reservedDBInstancesOfferingId)
      .optionallyWith(dbInstanceClass.map(value => value: java.lang.String))(
        _.dbInstanceClass
      )
      .optionallyWith(duration.map(value => value: java.lang.String))(
        _.duration
      )
      .optionallyWith(productDescription.map(value => value: java.lang.String))(
        _.productDescription
      )
      .optionallyWith(offeringType.map(value => value: java.lang.String))(
        _.offeringType
      )
      .optionallyWith(
        multiAZ.map(value => BooleanOptional.unwrap(value): java.lang.Boolean)
      )(_.multiAZ)
      .optionallyWith(leaseId.map(value => value: java.lang.String))(_.leaseId)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxRecords.map(value => IntegerOptional.unwrap(value): Integer)
      )(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.DescribeReservedDbInstancesRequest.ReadOnly =
    zio.aws.rds.model.DescribeReservedDbInstancesRequest.wrap(buildAwsValue())
}
object DescribeReservedDbInstancesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeReservedDbInstancesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DescribeReservedDbInstancesRequest =
      zio.aws.rds.model.DescribeReservedDbInstancesRequest(
        reservedDBInstanceId.map(value => value),
        reservedDBInstancesOfferingId.map(value => value),
        dbInstanceClass.map(value => value),
        duration.map(value => value),
        productDescription.map(value => value),
        offeringType.map(value => value),
        multiAZ.map(value => value),
        leaseId.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def reservedDBInstanceId: scala.Option[String]
    def reservedDBInstancesOfferingId: scala.Option[String]
    def dbInstanceClass: scala.Option[String]
    def duration: scala.Option[String]
    def productDescription: scala.Option[String]
    def offeringType: scala.Option[String]
    def multiAZ: scala.Option[BooleanOptional]
    def leaseId: scala.Option[String]
    def filters: scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]]
    def maxRecords: scala.Option[IntegerOptional]
    def marker: scala.Option[String]
    def getReservedDBInstanceId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("reservedDBInstanceId", reservedDBInstanceId)
    def getReservedDBInstancesOfferingId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "reservedDBInstancesOfferingId",
        reservedDBInstancesOfferingId
      )
    def getDbInstanceClass: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("dbInstanceClass", dbInstanceClass)
    def getDuration: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("duration", duration)
    def getProductDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("productDescription", productDescription)
    def getOfferingType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("offeringType", offeringType)
    def getMultiAZ: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField("multiAZ", multiAZ)
    def getLeaseId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("leaseId", leaseId)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.rds.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeReservedDbInstancesRequest
  ) extends zio.aws.rds.model.DescribeReservedDbInstancesRequest.ReadOnly {
    override val reservedDBInstanceId: scala.Option[String] =
      scala.Option(impl.reservedDBInstanceId()).map(value => value: String)
    override val reservedDBInstancesOfferingId: scala.Option[String] = scala
      .Option(impl.reservedDBInstancesOfferingId())
      .map(value => value: String)
    override val dbInstanceClass: scala.Option[String] =
      scala.Option(impl.dbInstanceClass()).map(value => value: String)
    override val duration: scala.Option[String] =
      scala.Option(impl.duration()).map(value => value: String)
    override val productDescription: scala.Option[String] =
      scala.Option(impl.productDescription()).map(value => value: String)
    override val offeringType: scala.Option[String] =
      scala.Option(impl.offeringType()).map(value => value: String)
    override val multiAZ: scala.Option[BooleanOptional] = scala
      .Option(impl.multiAZ())
      .map(value => zio.aws.rds.model.primitives.BooleanOptional(value))
    override val leaseId: scala.Option[String] =
      scala.Option(impl.leaseId()).map(value => value: String)
    override val filters
        : scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.rds.model.Filter.wrap(item)
        }.toList
      )
    override val maxRecords: scala.Option[IntegerOptional] = scala
      .Option(impl.maxRecords())
      .map(value => zio.aws.rds.model.primitives.IntegerOptional(value))
    override val marker: scala.Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeReservedDbInstancesRequest
  ): zio.aws.rds.model.DescribeReservedDbInstancesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-rds_2.12-5.17.152.1-sources.jar: zio/aws/rds/model/DescribeReservedDbInstancesRequest.scala <==
package zio.aws.rds.model
import java.lang.Integer
import zio.aws.rds.model.primitives.{IntegerOptional, BooleanOptional}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeReservedDbInstancesRequest(
    reservedDBInstanceId: scala.Option[String] = None,
    reservedDBInstancesOfferingId: scala.Option[String] = None,
    dbInstanceClass: scala.Option[String] = None,
    duration: scala.Option[String] = None,
    productDescription: scala.Option[String] = None,
    offeringType: scala.Option[String] = None,
    multiAZ: scala.Option[BooleanOptional] = None,
    leaseId: scala.Option[String] = None,
    filters: scala.Option[Iterable[zio.aws.rds.model.Filter]] = None,
    maxRecords: scala.Option[IntegerOptional] = None,
    marker: scala.Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeReservedDbInstancesRequest = {
    import DescribeReservedDbInstancesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeReservedDbInstancesRequest
      .builder()
      .optionallyWith(
        reservedDBInstanceId.map(value => value: java.lang.String)
      )(_.reservedDBInstanceId)
      .optionallyWith(
        reservedDBInstancesOfferingId.map(value => value: java.lang.String)
      )(_.reservedDBInstancesOfferingId)
      .optionallyWith(dbInstanceClass.map(value => value: java.lang.String))(
        _.dbInstanceClass
      )
      .optionallyWith(duration.map(value => value: java.lang.String))(
        _.duration
      )
      .optionallyWith(productDescription.map(value => value: java.lang.String))(
        _.productDescription
      )
      .optionallyWith(offeringType.map(value => value: java.lang.String))(
        _.offeringType
      )
      .optionallyWith(multiAZ.map(value => value: java.lang.Boolean))(_.multiAZ)
      .optionallyWith(leaseId.map(value => value: java.lang.String))(_.leaseId)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(maxRecords.map(value => value: Integer))(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.DescribeReservedDbInstancesRequest.ReadOnly =
    zio.aws.rds.model.DescribeReservedDbInstancesRequest.wrap(buildAwsValue())
}
object DescribeReservedDbInstancesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeReservedDbInstancesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DescribeReservedDbInstancesRequest =
      zio.aws.rds.model.DescribeReservedDbInstancesRequest(
        reservedDBInstanceId.map(value => value),
        reservedDBInstancesOfferingId.map(value => value),
        dbInstanceClass.map(value => value),
        duration.map(value => value),
        productDescription.map(value => value),
        offeringType.map(value => value),
        multiAZ.map(value => value),
        leaseId.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def reservedDBInstanceId: scala.Option[String]
    def reservedDBInstancesOfferingId: scala.Option[String]
    def dbInstanceClass: scala.Option[String]
    def duration: scala.Option[String]
    def productDescription: scala.Option[String]
    def offeringType: scala.Option[String]
    def multiAZ: scala.Option[BooleanOptional]
    def leaseId: scala.Option[String]
    def filters: scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]]
    def maxRecords: scala.Option[IntegerOptional]
    def marker: scala.Option[String]
    def getReservedDBInstanceId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("reservedDBInstanceId", reservedDBInstanceId)
    def getReservedDBInstancesOfferingId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "reservedDBInstancesOfferingId",
        reservedDBInstancesOfferingId
      )
    def getDbInstanceClass: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("dbInstanceClass", dbInstanceClass)
    def getDuration: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("duration", duration)
    def getProductDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("productDescription", productDescription)
    def getOfferingType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("offeringType", offeringType)
    def getMultiAZ: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField("multiAZ", multiAZ)
    def getLeaseId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("leaseId", leaseId)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.rds.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeReservedDbInstancesRequest
  ) extends zio.aws.rds.model.DescribeReservedDbInstancesRequest.ReadOnly {
    override val reservedDBInstanceId: scala.Option[String] =
      scala.Option(impl.reservedDBInstanceId()).map(value => value: String)
    override val reservedDBInstancesOfferingId: scala.Option[String] = scala
      .Option(impl.reservedDBInstancesOfferingId())
      .map(value => value: String)
    override val dbInstanceClass: scala.Option[String] =
      scala.Option(impl.dbInstanceClass()).map(value => value: String)
    override val duration: scala.Option[String] =
      scala.Option(impl.duration()).map(value => value: String)
    override val productDescription: scala.Option[String] =
      scala.Option(impl.productDescription()).map(value => value: String)
    override val offeringType: scala.Option[String] =
      scala.Option(impl.offeringType()).map(value => value: String)
    override val multiAZ: scala.Option[BooleanOptional] =
      scala.Option(impl.multiAZ()).map(value => value: BooleanOptional)
    override val leaseId: scala.Option[String] =
      scala.Option(impl.leaseId()).map(value => value: String)
    override val filters
        : scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.rds.model.Filter.wrap(item)
        }.toList
      )
    override val maxRecords: scala.Option[IntegerOptional] =
      scala.Option(impl.maxRecords()).map(value => value: IntegerOptional)
    override val marker: scala.Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeReservedDbInstancesRequest
  ): zio.aws.rds.model.DescribeReservedDbInstancesRequest.ReadOnly =
    new Wrapper(impl)
}
